'use strict';

const expect = require('chai').expect;
const constants = require('./utils/constants');
const cliWrapper = require('./utils/cli-wrapper');
const responseParser = require('./utils/response-parser');
const message = require('./utils/messages');
const fs = require("fs");
const timeout = 80000;
let skillId;

describe('create skill tests', function() {
    this.timeout(timeout);
    it('| create skill with valid skill id and file', (done) => {
        cliWrapper.callCreateSkill('./test/functional/fixture/custom-skill/skill.json', constants.testData.PROFILE, (error, stdout, stderr) => {
            if (error) {
                    console.log(error);
                    done(error);
            } else {
                    skillId = responseParser.getSkillID(stdout);
                    expect(stdout.startsWith(message.CREATE_SKILL_SUBMITED)).equal(true);
                    done();
            }
        });
    });

    it ('| create skill with invalid file path', (done) => {
        cliWrapper.callCreateSkill('./test/functional/fixture/custom-skill', constants.testData.PROFILE, (error, stdout, stderr) => {
            expect(error);
            expect(stderr.startsWith(message.INVALID_FILE_PATH_MSG) > -1).equal(true);
            done();
        });
    });
 

    after("tear down", function(){
        this.timeout(timeout);
        it ('| delete skill test', (done) => {
            cliWrapper.callDeleteSkill(skillId, constants.testData.PROFILE, (error, stdout, stderr) => {
                if (error) {
                    console.log(error);
                    done(error);
                } else {
                    expect(stdout).equal(message.DELETE_SKILL);
                    done();
                }
            });
        }); 
    });
});
