'use strict';

const expect = require('chai').expect;
const constants = require('./utils/constants');
const cliWrapper = require('./utils/cli-wrapper');
const message = require('./utils/messages');
const fs = require("fs");
const os = require('os');
let skillId;
const timeout = 80000;

describe('# list vendors', function() {
    this.timeout(timeout);
    it ('| list vendors test with profile', (done) => {
        cliWrapper.callListVendors(constants.testData.PROFILE, (error, stdout, stderr) => {
            if (error) {
                console.log(error);
                done(error);
            } else {
                const getListVendorsResponse = JSON.parse(stdout);
                const actualVendorId = getListVendorsResponse[0]['id'];
                fs.readFile( os.homedir() + "/.ask/cli_config", 'utf8', function (err, data) {
                    if (err) throw err;
                    const profileInfo = JSON.parse(data);
                    const expectedVendorId = profileInfo['profiles'][constants.testData.PROFILE]['vendor_id'];
                    expect(actualVendorId).equal(expectedVendorId);
                });
                done();
            }
        });
    });
    it ('| list vendors test without profile', (done) => {
        cliWrapper.callListVendors(null, (error, stdout, stderr) => {
            if (error) {
                console.log(error);
                done(error);
            } else {
                const getListVendorsResponse = JSON.parse(stdout);
                const actualVendorId = getListVendorsResponse[0]['id'];
                fs.readFile( os.homedir() + "/.ask/cli_config", 'utf8', function (err, data) {
                    if (err) throw err;
                    const profileInfo = JSON.parse(data);
                    const expectedVendorId = profileInfo['profiles'][constants.testData.DEFAULT]['vendor_id'];
                    expect(actualVendorId).equal(expectedVendorId);
                });
                done();
            }
        });
    });
});
