'use strict';

const expect = require('chai').expect;
const constants = require('./utils/constants');
const cliWrapper = require('./utils/cli-wrapper');
const message = require('./utils/messages');
const fs = require("fs");
const timeout = 80000;

describe('# update skill tests', function() {
    this.timeout(timeout);
    it('| update skill with valid skill id and file', (done) => {
        cliWrapper.callUpdateSkill(constants.testData.VALID_SKILL_ID, constants.testData.DEVELOPMENT_STAGE, './test/functional/fixture/custom-skill/skill.json', constants.testData.PROFILE, (error, stdout, stderr) => {
            if (error) {
                console.log(error);
                done(error);
            } else {
                expect(stdout.startsWith(message.UPDATE_SKILL_SUBMITED)).equal(true);
                done();
            }
        });
    });

    it ('| update skill with invalid skill id', (done) => {
        cliWrapper.callUpdateSkill(constants.testData.INVALID_SKILL_ID, constants.testData.DEVELOPMENT_STAGE, './test/functional/fixture/custom-skill/skill.json', constants.testData.PROFILE, (error, stdout, stderr) => {
            expect(error);
            expect(stderr.startsWith(message.UPDATE_SKILL_ERROR_MSG) > -1).equal(true);
            done();
        });
    });

    it ('| update skill with invalid file path', (done) => {
        cliWrapper.callUpdateSkill(constants.testData.VALID_SKILL_ID, constants.testData.DEVELOPMENT_STAGE, './test/functional/fixture/custom-skill', constants.testData.PROFILE, (error, stdout, stderr) => {
            expect(error);
            expect(stderr.startsWith(message.INVALID_FILE_PATH_MSG) > -1).equal(true);
            done();
        });
    });
});

